@@ -16,11 +16,14 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <kapplication.h>
-#include <klocale.h>
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
 
+
+#include <KAboutData>
+#include <QApplication>
+#include <KLocalizedString>
+#include <QCommandLineParser>
+#include <kdelibs4configmigrator.h>
+#include <KDBusService>
 #include "ktimer.h"
 
 static const char description[] =
@@ -30,18 +33,35 @@ static const char version[] = "v0.10";
 
 int main( int argc, char **argv )
 {
-    KAboutData aboutData( "ktimer", 0, ki18n("KTimer"),
-                          version, ki18n(description), KAboutData::License_GPL,
-                          ki18n("(c) 2001, Stefan Schimanski"), KLocalizedString(),
+    QApplication app(argc, argv);
+
+    /**
+     * enable high dpi support
+     */
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+
+    Kdelibs4ConfigMigrator migrate(QStringLiteral("ktimer"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("ktimerrc"));
+    migrate.migrate();
+
+    KAboutData aboutData( "ktimer", i18n("KTimer"),
+                          version, i18n(description), KAboutLicense::GPL,
+                          i18n("(c) 2001, Stefan Schimanski"),
                           "http://utils.kde.org/projects/ktimer");
-    aboutData.addAuthor(ki18n("Stefan Schimanski"),KLocalizedString(), "schimmi@kde.org");
-    KCmdLineArgs::init( argc, argv, &aboutData );
+    aboutData.addAuthor(i18n("Stefan Schimanski"),QString(), "schimmi@kde.org");
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(aboutData);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 
-    KApplication app;
     app.setQuitOnLastWindowClosed( false );
+    KDBusService service;
 
     KTimerPref *timer = new KTimerPref;
-    app.setTopWidget( timer );
+    timer->show();
 
     return app.exec();
 }
